@@ -33,9 +33,10 @@
 #  define KACTIVITIESSTATS_DEPRECATED_NO_EXPORT KACTIVITIESSTATS_NO_EXPORT KACTIVITIESSTATS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KACTIVITIESSTATS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KACTIVITIESSTATS_NO_DEPRECATED
+#    define KACTIVITIESSTATS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
